
# Type: s1




URI: [ex:s1](http://example.org/mappings/s1)


## Domain and Range

[C1](C1.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [C1](C1.md)
 * [C2](C2.md)
 * [C3](C3.md)
